@@ -2,23 +2,27 @@
 #######################################################################
 """Interfaces for the Zope 3 based product package
 
-$Id: interfaces.py 51919 2008-10-21 19:01:53Z cray $
+$Id: interfaces.py 52470 2009-02-07 09:25:57Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 51919 $"
+__version__ = "$Revision: 52470 $"
  
 from ng.content.annotation.annotationswitcher.interfaces import IAnnotationSwitcher
 from ng.content.annotation.dictannotation.interfaces import IDictAnnotationAble
 from ng.content.annotation.eventannotation.interfaces import IEventAnnotationAble
 from ng.content.annotation.productannotation.interfaces import IProductAnnotationAble
+from ng.content.annotation.redirectannotation.interfaces import IRedirectAnnotationAble
 
 class IAnnotationSwitcherDict(IAnnotationSwitcher,IDictAnnotationAble) :
-    """Use as dictionary """
+    """Dictionary item"""
 
 class IAnnotationSwitcherEvent(IAnnotationSwitcher,IEventAnnotationAble) :
-    """Use as Event """
+    """Event"""
 
 class IAnnotationSwitcherProduct(IAnnotationSwitcher,IProductAnnotationAble) :
-    """Use as Product """
+    """Product news"""
+
+class IAnnotationSwitcherRedirect(IAnnotationSwitcher,IRedirectAnnotationAble) :
+    """Redirect"""
 
