@@ -2,11 +2,11 @@
 #######################################################################
 """Interfaces for the Zope 3 based product package
 
-$Id: interfaces.py 51919 2008-10-21 19:01:53Z cray $
+$Id: interfaces.py 52310 2009-01-12 21:36:45Z cray $
 """
 __author__  = "Elena Antusheva, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 51919 $"
+__version__ = "$Revision: 52310 $"
  
 from zope.interface import Interface
 
@@ -16,12 +16,10 @@ from ng.schema.interfaceswitcher.interfacechoicefield import InterfaceChoice
 
 class IAnnotationSwitcher(Interface) :
     iface = InterfaceSet(
-        title=u"Interface list",
+        title=u"Content extension list",
         default = set([]),
         missing_value = set([])
         )
 
 IAnnotationSwitcher['iface'].iface = IAnnotationSwitcher
-    
-
     
\ No newline at end of file
