@@ -13,6 +13,8 @@ from zope.annotation.interfaces import IAnnotations
 from zope.schema import getFieldNames
 
 from interfaces import dictannotationkey
+from zope.location.location import LocationProxy 
+
 
 def IDictAnnotationAbleAdapter(context) :
 
@@ -20,4 +22,4 @@ def IDictAnnotationAbleAdapter(context) :
         an = IAnnotations(context)[dictannotationkey]
     except KeyError :
         an = IAnnotations(context)[dictannotationkey] = DictAnnotation()
-    return an
+    return LocationProxy(an, context, "++annotations++" + dictannotationkey)
