@@ -3,11 +3,11 @@
 """The adapter ProductAnnotation2TitleSubscriber that adopt IAttributeAnnotatable
    interface to ITitle interface
 
-$Id: productannotation2titlesubscriber.py 51919 2008-10-21 19:01:53Z cray $
+$Id: productannotation2titlesubscriber.py 52274 2009-01-07 13:03:45Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51919 $"
+__version__ = "$Revision: 52274 $"
 
 from interfaces import IProductAnnotation
 from ng.adapter.ianytitle.anytitlesubscriberbase import AnyTitleSubscriberBase
@@ -18,5 +18,5 @@ class ProductAnnotation2TitleSubscriber( AnyTitleSubscriberBase ) :
 
     @property
     def title(self) :
-        return IProductAnnotation(self.context).place
+        return IProductAnnotation(self.context).title
 
