@@ -3,17 +3,17 @@
 """ProductAnnotationAbleAdapter class for the Zope 3 based
 ng.content.annotation.productannotation package
 
-$Id: productannotationableadapter.py 51919 2008-10-21 19:01:53Z cray $
+$Id: productannotationableadapter.py 52471 2009-02-07 20:56:31Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51919 $"
+__version__ = "$Revision: 52471 $"
 
 
 from zope.annotation.interfaces import IAnnotations 
 from productannotation import ProductAnnotation
 from interfaces import productannotationkey
-
+from zope.location.location import LocationProxy 
 
 def ProductAnnotationAbleAdapter(context) :
     annotations = IAnnotations(context)
@@ -21,4 +21,4 @@ def ProductAnnotationAbleAdapter(context) :
         ea = annotations[productannotationkey]
     except KeyError :
         ea = annotations[productannotationkey] = ProductAnnotation()
-    return ea
+    return LocationProxy(ea, context, "++annotations++" +  productannotationkey)
